BaseGuard

Trait BaseGuard 

pub trait BaseGuard {
    type State: Clone + Copy;

    // Required methods
    fn acquire() -> Self::State;
    fn release(state: Self::State);

    // Provided method
    fn lockdep_enabled() -> bool { ... }
}
A base trait that all guards implement.

Required Associated Types

type State: Clone + Copy

The saved state when entering the critical section.

Required Methods

fn acquire() -> Self::State

Something that must be done before entering the critical section.

fn release(state: Self::State)

Something that must be done after leaving the critical section.

Provided Methods

fn lockdep_enabled() -> bool

Returns whether locks guarded by this type should participate in lock dependency tracking.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors